jactorch.nn.neural\_logic.layer
===============================

.. automodule:: jactorch.nn.neural_logic.layer

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      NeuralLogicLayer
      NeuralLogicMachine
   
   

   
   
   

   
   
   








.. rubric:: Class NeuralLogicLayer
.. autoclass:: NeuralLogicLayer
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class NeuralLogicMachine
.. autoclass:: NeuralLogicMachine
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







